STIS ImageObjects — drizzlepac 1.0.6 (14-Aug-2012) documentation

### Navigation

- index
- modules |
- next |
- previous |
- drizzlepac 1.0.6 (14-Aug-2012) documentation »
- imageObject Classes »

# STIS ImageObjects

class `drizzlepac.stisData.` `STISInputImage`(filename=None, group=None)

  Bases: `drizzlepac.imageObject.imageObject`

  `doUnitConversions`()

    Convert the data to electrons.

    This converts all science data extensions and saves the results back to disk. We need to make sure the data inside the chips already in memory is altered as well.

  `getflat`(chip)

    Method for retrieving a detector’s flat field. For STIS there are three. This method will return an array the same shape as the image.

  `SEPARATOR` = '_'

class `drizzlepac.stisData.` `CCDInputImage`(filename=None, group=None)

  Bases: `drizzlepac.stisData.STISInputImage`

  `getReadNoise`()

    Method for returning the readnoise of a detector (in DN).

    Units :
    | DN

    This should work on a chip, since different chips to be consistant with other detector classes where different chips have different gains.

  `getdarkcurrent`()

    Returns the dark current for the STIS CCD chip.

    Returns :
    | darkcurrent : float Dark current value in units of electrons (or counts, if proc_unit==’native’).

  `setInstrumentParameters`(instrpars)

    This method overrides the superclass to set default values into the parameter dictionary, in case empty entries are provided.

class `drizzlepac.stisData.` `NUVInputImage`(input, dqname, platescale, memmap=0, proc_unit='native')

  Bases: `drizzlepac.stisData.STISInputImage`

  `getdarkcurrent`()

    Returns the dark current for the STIS NUV detector.

    Returns :
    | darkcurrent : float Dark current value in units of electrons (or counts, if proc_unit==’native’).

  `setInstrumentParameters`(instrpars)

    This method overrides the superclass to set default values into the parameter dictionary, in case empty entries are provided.

class `drizzlepac.stisData.` `FUVInputImage`(filename=None, group=None)

  Bases: `drizzlepac.stisData.STISInputImage`

  `getdarkcurrent`()

    Returns the dark current for the STIS FUV detector.

    Returns :
    | darkcurrent : float Dark current value in units of electrons (or counts, if proc_unit==’native’).

  `setInstrumentParameters`(instrpars)

    This method overrides the superclass to set default values into the parameter dictionary, in case empty entries are provided.

### Navigation

- index
- modules |
- next |
- previous |
- drizzlepac 1.0.6 (14-Aug-2012) documentation »
- imageObject Classes »